Interactive tutorials
=====================

If you're new to Python or simply want to quickly explore the basic features of metasyn,
you can try our interactive tutorial. It provides a step-by-step walkthrough and example dataset
to help you get started.

You can access it here:
   - Google Colab: `Open in Google Colab <https://colab.research.google.com/github/sodascience/metasyn/blob/main/examples/getting_started.ipynb>`__
   - GitHub: `View on GitHub <https://github.com/sodascience/metasyn/blob/main/examples/getting_started.ipynb>`__
